Index: trunk/psLib/src/sys/psString.c
===================================================================
--- trunk/psLib/src/sys/psString.c	(revision 4401)
+++ trunk/psLib/src/sys/psString.c	(revision 4409)
@@ -12,6 +12,6 @@
  *  @author Eric Van Alst, MHPCC
  *
- *  @version $Revision: 1.17 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-05-20 01:41:17 $
+ *  @version $Revision: 1.18 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -26,13 +26,13 @@
 #include "psSysUtilsErrors.h"
 
-char *psStringCopy(const char *str)
+psString psStringCopy(const char *string)
 {
     // Allocate memory using psAlloc function
     // Copy input string to memory just allocated
     // Return the copy
-    return strcpy(psAlloc(strlen(str) + 1), str);
+    return strcpy(psAlloc(strlen(string) + 1), string);
 }
 
-char *psStringNCopy(const char *str, psS32 nChar)
+psString psStringNCopy(const char *string, int nChar)
 {
     char *returnValue = NULL;
@@ -49,5 +49,5 @@
     // Copy input string to memory allocated up to nChar characters
     // Return the copy
-    returnValue = strncpy(psAlloc((size_t) nChar + 1), str, (size_t) nChar);
+    returnValue = strncpy(psAlloc((size_t) nChar + 1), string, (size_t) nChar);
 
     // Ensure the last byte is NULL character
Index: trunk/psLib/src/sys/psTrace.c
===================================================================
--- trunk/psLib/src/sys/psTrace.c	(revision 4401)
+++ trunk/psLib/src/sys/psTrace.c	(revision 4409)
@@ -9,6 +9,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.52 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-25 02:02:05 $
+ *  @version $Revision: 1.53 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -57,10 +57,10 @@
 
 static void componentFree(p_psComponent* comp);
-static p_psComponent* componentAlloc(const char *name, psS32 level);
+static p_psComponent* componentAlloc(const char *name, int level);
 
 /*****************************************************************************
 componentAlloc(): allocate memory for a new node, and initialize members.
  *****************************************************************************/
-static p_psComponent* componentAlloc(const char *name, psS32 level)
+static p_psComponent* componentAlloc(const char *name, int level)
 {
     p_psComponent* comp = psAlloc(sizeof(p_psComponent));
@@ -245,5 +245,5 @@
 *****************************************************************************/
 psBool psTraceSetLevel(const char *comp,   // component of interest
-                       psS32 level)  // desired trace level
+                       int level)  // desired trace level
 {
     char *compName = NULL;
@@ -487,6 +487,6 @@
  *****************************************************************************/
 void p_psTrace(const char *comp,        // component being traced
-               psS32 level,       // desired trace level
-               ...)             // arguments
+               int level,               // desired trace level
+               ...)                     // arguments
 {
     char *fmt = NULL;
Index: trunk/psLib/src/sys/psTrace.h
===================================================================
--- trunk/psLib/src/sys/psTrace.h	(revision 4401)
+++ trunk/psLib/src/sys/psTrace.h	(revision 4409)
@@ -9,6 +9,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.33 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-21 03:01:37 $
+ *  @version $Revision: 1.34 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -60,14 +60,17 @@
 
 #ifdef DOXYGEN
-void psTrace(const char *facil,        ///< facilty of interest
-             psS32 myLevel,            ///< desired trace level
-             ...)                      ///< trace message arguments
-;
+void psTrace(
+    const char *facil,                 ///< facilty of interest
+    int level,                         ///< desired trace level
+    ...                                ///< trace message arguments
+);
+
 #else
 /// Send a trace message
-void p_psTrace(const char *facil,      ///< facilty of interest
-               psS32 myLevel,          ///< desired trace level
-               ...)                    ///< trace message arguments
-;
+void p_psTrace(
+    const char *facil,                 ///< facilty of interest
+    psS32 myLevel,                     ///< desired trace level
+    ...                                ///< trace message arguments
+);
 
 #ifndef SWIG
@@ -78,7 +81,8 @@
 
 /// Set trace level
-psBool psTraceSetLevel(const char *facil,     ///< facilty of interest
-                       psS32 level)     ///< desired trace level
-;
+psBool psTraceSetLevel(
+    const char *facil,                 ///< facilty of interest
+    int level                          ///< desired trace level
+);
 
 /// Get the trace level
@@ -94,5 +98,7 @@
 
 /// Set the destination of future trace messages.
-void psTraceSetDestination(FILE * fp);
+void psTraceSetDestination(
+    FILE * fp                          ///<
+);
 
 /// Get the current destination for trace messages.

Index: trunk/psLib/src/sys/psString.h
===================================================================
--- trunk/psLib/src/sys/psString.h	(revision 4401)
+++ trunk/psLib/src/sys/psString.h	(revision 4409)
@@ -13,6 +13,6 @@
  *  @author Eric Van Alst, MHPCC
  *
- *  @version $Revision: 1.13 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-08 23:40:45 $
+ *  @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -39,10 +39,9 @@
  *  plus one and copy the input string to the newly allocated memory.
  *
  *  @return char*      Copy of input string
  *
  */
-char *psStringCopy(
-    const char *str
-    /**< Input string of characters to copy */
+psString psStringCopy(
+    const char *string                 ///< Input string of characters to copy
 );
 
@@ -57,5 +56,5 @@
  *  be set to NULL.
  *
  *  @return  char* Copy of input string
  *
  */
@@ -63,10 +62,7 @@
 /*@null@*/
 
-char *psStringNCopy(
-    const char *str,
-    /**< Input string of characters to copy */
-
-    psS32 nChar
-    /**< Number of bytes to allocate for string copy */
+psString psStringNCopy(
+    const char *string,                ///< Input string of characters to copy
+    int nChar                          ///< Number of bytes to allocate for string copy
 );
 
@@ -39,10 +39,9 @@
  *  plus one and copy the input string to the newly allocated memory.
  *
- *  @return char*      Copy of input string
+ *  @return psString:      Copy of input string
  *
  */
@@ -57,5 +56,5 @@
  *  be set to NULL.
  *
- *  @return  char* Copy of input string
+ *  @return  psString:   Copy of input string
  *
  */